@@ -6,10 +6,13 @@ import subprocess
 
 
 def linecount(path):
-    return wordcount(path, args="-l")
+    return wordcount(path, args=["-l"])
 
 
 def wordcount(path, args=["-w"]):
+    if isinstance(args, str):
+        args = args.split()
+
     o = subprocess.run(["wc"] + args + [path], stdout=subprocess.PIPE)
     wc = int(o.stdout.decode('utf-8').split()[0])
     return wc
